BluetoothDevice class

Constructors

BluetoothDevice({required String name, required String address, required bool paired})
BluetoothDevice.fromMap(dynamic map)
factory

Properties

address → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
paired → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited